#![allow(non_snake_case)]

mod components;

use dioxus::prelude::*;
use tracing::{info, Level};

// Include routes
use components::home::Home;

#[derive(Clone, Routable, Debug, PartialEq, serde::Serialize, serde::Deserialize)]
pub enum Route {
    #[layout(Wrapper)]
    #[route("/")]
    Home {},
}

const _TAILWIND_URL: &str = manganis::mg!(file("assets/tailwind.css"));

fn main() {
    // Init logger
    dioxus_logger::init(Level::INFO).expect("failed to init logger");
    launch(App);
}

#[component]
fn Wrapper() -> Element {
    rsx! {
        components::layout::topbar::Topbar {}
        main {
            class: "h-full",
            Outlet::<Route> {}
        }
        components::layout::navbar::Navbar {}
    }
}

fn App() -> Element {
    rsx! {
        div {
            class: "h-screen flex flex-col",
            Router::<Route> {}
        }
    }
}
